summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorkstailey <kstailey@cvs.openbsd.org>1997-02-04 01:31:36 +0000
committerkstailey <kstailey@cvs.openbsd.org>1997-02-04 01:31:36 +0000
commit4cb72130da46efb397c528102c1410f3ff45c5b8 (patch)
tree534c6d1814ba4c76d61bc14e6a3acbf1d48e50b6
parent2a23aa154b71bafe5525623186d73bd9ab164232 (diff)
NetBSD -> OpenBSD
-rw-r--r--sys/arch/sun3/sun3/disksubr.c8
-rw-r--r--sys/arch/sun3/sun3/locore.s8
-rw-r--r--sys/arch/sun3/sun3/trap.c4
3 files changed, 10 insertions, 10 deletions
diff --git a/sys/arch/sun3/sun3/locore.s b/sys/arch/sun3/sun3/locore.s
index 16f91d17760..b843b27e54e 100644
--- a/sys/arch/sun3/sun3/locore.s
+++ b/sys/arch/sun3/sun3/locore.s
@@ -1,4 +1,4 @@
-/* $OpenBSD: locore.s,v 1.9 1997/02/03 21:30:13 kstailey Exp $ */
+/* $OpenBSD: locore.s,v 1.10 1997/02/04 01:31:34 kstailey Exp $ */
/* $NetBSD: locore.s,v 1.40 1996/11/06 20:19:54 cgd Exp $ */
/*
@@ -442,7 +442,7 @@ _trap0:
/*
* Trap 1 is either:
- * sigreturn (native NetBSD executable)
+ * sigreturn (native OpenBSD executable)
* breakpoint (HPUX executable)
*/
_trap1:
@@ -491,7 +491,7 @@ Lsigr1:
/*
* Trap 2 is one of:
- * NetBSD: not used (ignore)
+ * OpenBSD: not used (ignore)
* SunOS: Some obscure FPU operation
* HPUX: sigreturn
*/
@@ -500,7 +500,7 @@ _trap2:
/* XXX: If HPUX, this is a user breakpoint. */
jne sigreturn
#endif
- /* fall into trace (NetBSD or SunOS) */
+ /* fall into trace (OpenBSD or SunOS) */
/*
* Trace (single-step) trap. Kernel-mode is special.
diff --git a/sys/arch/sun3/sun3/trap.c b/sys/arch/sun3/sun3/trap.c
index cd8d44bb1eb..5cbfc483953 100644
--- a/sys/arch/sun3/sun3/trap.c
+++ b/sys/arch/sun3/sun3/trap.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: trap.c,v 1.12 1997/02/03 23:32:22 kstailey Exp $ */
+/* $OpenBSD: trap.c,v 1.13 1997/02/04 01:31:35 kstailey Exp $ */
/* $NetBSD: trap.c,v 1.63-1.65ish 1997/01/16 15:41:40 gwr Exp $ */
/*
@@ -385,7 +385,7 @@ trap(type, code, v, frame)
* XXX: Trace traps are a nightmare.
*
* HP-UX uses trap #1 for breakpoints,
- * NetBSD/m68k uses trap #2,
+ * OpenBSD/m68k uses trap #2,
* SUN 3.x uses trap #15,
* KGDB uses trap #15 (for kernel breakpoints; handled elsewhere).
*
diff --git a/sys/arch/sun3/sun3/disksubr.c b/sys/arch/sun3/sun3/disksubr.c
index 25415c74ac1..9eb01e5ec21 100644
--- a/sys/arch/sun3/sun3/disksubr.c
+++ b/sys/arch/sun3/sun3/disksubr.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: disksubr.c,v 1.8 1997/01/16 04:04:18 kstailey Exp $ */
+/* $OpenBSD: disksubr.c,v 1.9 1997/02/04 01:31:33 kstailey Exp $ */
/* $NetBSD: disksubr.c,v 1.14 1996/09/26 18:10:21 gwr Exp $ */
/*
@@ -126,11 +126,11 @@ readdisklabel(dev, strat, lp, clp)
return(disklabel_sun_to_bsd(clp->cd_block, lp));
}
/* Check for a NetBSD disk label (PROM can not boot it). */
dlp = (struct disklabel *) (clp->cd_block + LABELOFFSET);
if (dlp->d_magic == DISKMAGIC) {
if (dkcksum(dlp))
- return("NetBSD disk label corrupted");
+ return("OpenBSD disk label corrupted");
*lp = *dlp; /* struct assignment */
return(NULL);
}
@@ -204,7 +204,7 @@ writedisklabel(dev, strat, lp, clp)
if (error)
return(error);
-#if 0 /* XXX - Allow writing NetBSD disk labels? */
+#if 0 /* XXX - Allow writing OpenBSD disk labels? */
{
struct disklabel *dlp;
dlp = (struct disklabel *)(clp->cd_block + LABELOFFSET);
@@ -126,11 +126,11 @@ readdisklabel(dev, strat, lp, clp)
return(disklabel_sun_to_bsd(clp->cd_block, lp));
}
- /* Check for a NetBSD disk label (PROM can not boot it). */
+ /* Check for a OpenBSD disk label (PROM can not boot it). */
dlp = (struct disklabel *) (clp->cd_block + LABELOFFSET);
if (dlp->d_magic == DISKMAGIC) {